Index: test/mjsunit/regress/regress-opt-after-debug-deopt.js |
diff --git a/test/mjsunit/regress/regress-opt-after-debug-deopt.js b/test/mjsunit/regress/regress-opt-after-debug-deopt.js |
index 3de0217c8152d311fb4c5f070dae4ca2733aafac..8bf95ec5aada4cc57a192e11875b4ad2225d0199 100644 |
--- a/test/mjsunit/regress/regress-opt-after-debug-deopt.js |
+++ b/test/mjsunit/regress/regress-opt-after-debug-deopt.js |
@@ -26,10 +26,10 @@ |
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
// Flags: --expose-debug-as debug --allow-natives-syntax |
-// Flags: --parallel-recompilation --parallel-recompilation-delay=100 |
+// Flags: --concurrent-recompilation --concurrent-recompilation-delay=100 |
-if (!%IsParallelRecompilationSupported()) { |
- print("Parallel recompilation is disabled. Skipping this test."); |
+if (!%IsConcurrentRecompilationSupported()) { |
+ print("Concurrent recompilation is disabled. Skipping this test."); |
quit(); |
} |
@@ -57,12 +57,12 @@ var f = function() { |
f(); |
f(); |
-%OptimizeFunctionOnNextCall(f, "parallel"); // Mark with builtin. |
-f(); // Kick off parallel recompilation. |
+%OptimizeFunctionOnNextCall(f, "concurrent"); // Mark with builtin. |
+f(); // Kick off concurrent recompilation. |
Debug.setListener(listener); // Activate debugger. |
Debug.setBreakPoint(f, 2, 0); // Force deopt. |
-// Sync with parallel optimization thread. But no optimized code is installed. |
+// Sync with optimization thread. But no optimized code is installed. |
assertUnoptimized(f, "sync"); |
f(); // Trigger break point. |